
#ifndef _C128_re6373_
#define _C128_re6373_

#ifdef __cplusplus
extern "C" {
#endif

extern void F7901_115892(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit6373(void);
extern char *(*R20611[])();

#ifdef __cplusplus
}
#endif

#endif
